@@ -1,5 +1,7 @@
 library(testthat)
 library(tidyquant)
 library(tidyverse)
+library(dplyr)
+library(tibble)
 
 test_check("tidyquant")
